pub struct CheckBox<T: Model> { /* private fields */ }Trait Implementations
Sourceimpl<T: Model + Clone> Component for CheckBox<T>
impl<T: Model + Clone> Component for CheckBox<T>
Sourcetype Message = CheckBoxMessage
type Message = CheckBoxMessage
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcetype Properties = CheckBoxProperties<T>
type Properties = CheckBoxProperties<T>
Properties are the inputs to a Component and should not mutated within a
Component. They are passed to a Component using a JSX-style syntax. Read more
Sourcefn create(props: Self::Properties, link: ComponentLink<Self>) -> Self
fn create(props: Self::Properties, link: ComponentLink<Self>) -> Self
Components are created with their properties as well as a
ComponentLink which
can be used to send messages and create callbacks for triggering updates.Sourcefn update(&mut self, msg: Self::Message) -> bool
fn update(&mut self, msg: Self::Message) -> bool
Components handle messages in their
update method and commonly use this method
to update their state and (optionally) re-render themselves.Sourcefn change(&mut self, _props: Self::Properties) -> bool
fn change(&mut self, _props: Self::Properties) -> bool
When the parent of a Component is re-rendered, it will either be re-created or
receive new properties in the
change lifecycle method. Component’s can choose
to re-render if the new properties are different than the previously
received properties. Most Component’s will use props with a PartialEq
impl and will be implemented like this: Read moreSourcefn view(&self) -> Html
fn view(&self) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation.Auto Trait Implementations
impl<T> Freeze for CheckBox<T>
impl<T> !RefUnwindSafe for CheckBox<T>
impl<T> !Send for CheckBox<T>
impl<T> !Sync for CheckBox<T>
impl<T> Unpin for CheckBox<T>
impl<T> UnsafeUnpin for CheckBox<T>
impl<T> !UnwindSafe for CheckBox<T>